@@ -40,8 +40,8 @@ a shapefile and for each, picking off the first vertex of the exterior
 ring of the polygon and using that as the point geometry for a new
 feature writing to a "points.shp" file.
 
-  >>> from fiona import collection
-  >>> with collection("docs/data/test_uk.shp", "r") as inp:
+  >>> import fiona
+  >>> with fiona.open('docs/data/test_uk.shp', 'r') as inp:
   ...     output_schema = inp.schema.copy()
   ...     output_schema['geometry'] = 'Point'
   ...     with collection(
@@ -63,14 +63,24 @@ writing modes) flush contents to disk when their ``with`` blocks end.
 """
 
 __all__ = []
-__version__ = "0.14"
+__version__ = "0.15"
 
 import os
+from six import string_types
 
-from fiona.collection import Collection, supported_drivers
+from fiona.collection import Collection, supported_drivers, vsi_path
+from fiona.ogrext import _listlayers
 
 
-def open(path, mode='r', driver=None, schema=None, crs=None, encoding=None):
+def open(
+        path, 
+        mode='r', 
+        driver=None, 
+        schema=None, 
+        crs=None,
+        encoding=None,
+        layer=None,
+        vfs=None ):
     
     """Open file at ``path`` in ``mode`` "r" (read), "a" (append), or
     "w" (write) and return a ``Collection`` object.
@@ -92,15 +102,29 @@ def open(path, mode='r', driver=None, schema=None, crs=None, encoding=None):
     The drivers used by Fiona will try to detect the encoding of data
     files. If they fail, you may provide the proper ``encoding``, such as
     'Windows-1252' for the Natural Earth datasets.
+    
+    When the provided path is to a file containing multiple named layers
+    of data, a layer can be singled out by ``layer``.
+    
+    A virtual filesystem can be specified. The ``vfs`` parameter may be
+    an Apache Commons VFS style string beginning with "zip://" or
+    "tar://"". In this case, the ``path`` must be an absolute path within
+    that container.
     """
+    # Parse the vfs into a vsi and an archive path.
+    path, vsi, archive = parse_paths(path, vfs)
     if mode in ('a', 'r'):
-        if not os.path.exists(path):
+        if archive:
+            if not os.path.exists(archive):
+                raise IOError("no such archive file: %r" % archive)
+        elif not os.path.exists(path):
             raise IOError("no such file or directory: %r" % path)
-        c = Collection(path, mode, encoding=encoding)
+        c = Collection(path, mode, 
+                encoding=encoding, layer=layer, vsi=vsi, archive=archive)
     elif mode == 'w':
-        c = Collection(path, mode=mode, 
-            crs=crs, driver=driver, schema=schema, 
-            encoding=encoding)
+        c = Collection(path, mode, 
+                crs=crs, driver=driver, schema=schema, 
+                encoding=encoding, layer=layer, vsi=vsi, archive=archive)
     else:
         raise ValueError(
             "mode string must be one of 'r', 'w', or 'a', not %s" % mode)
@@ -108,6 +132,44 @@ def open(path, mode='r', driver=None, schema=None, crs=None, encoding=None):
 
 collection = open
 
+def listlayers(path, vfs=None):
+    """Returns a list of layer names in their index order.
+    
+    The required ``path`` argument may be an absolute or relative file or
+    directory path.
+    
+    A virtual filesystem can be specified. The ``vfs`` parameter may be
+    an Apache Commons VFS style string beginning with "zip://" or
+    "tar://"". In this case, the ``path`` must be an absolute path within
+    that container.
+    """
+    if not isinstance(path, string_types):
+        raise TypeError("invalid path: %r" % path)
+    if vfs and not isinstance(vfs, string_types):
+        raise TypeError("invalid vfs: %r" % vfs)
+    
+    path, vsi, archive = parse_paths(path, vfs)
+    
+    if archive:
+        if not os.path.exists(archive):
+            raise IOError("no such archive file: %r" % archive)
+    elif not os.path.exists(path):
+        raise IOError("no such file or directory: %r" % path)
+    
+    return _listlayers(vsi_path(path, vsi, archive))
+
+def parse_paths(path, vfs=None):
+    archive = vsi = None
+    if vfs:
+        parts = vfs.split("://")
+        vsi = parts.pop(0) if parts else None
+        archive = parts.pop(0) if parts else None
+    else:
+        parts = path.split("://")
+        path = parts.pop() if parts else None
+        vsi = parts.pop() if parts else None
+    return path, vsi, archive
+
 def prop_width(val):
     """Returns the width of a str type property.
 
@@ -121,3 +183,4 @@ def prop_width(val):
     if val.startswith('str'):
         return int((val.split(":")[1:] or ["80"])[0])
     return None
+
