@@ -35,21 +35,21 @@ class ReadingTest(unittest.TestCase):
     def test_open_repr(self):
         self.failUnlessEqual(
             repr(self.c),
-            ("<open Collection 'docs/data/test_uk.shp:test_uk', mode 'r' "
+            ("<open Collection 'docs/data/test_uk.shp:0', mode 'r' "
             "at %s>" % hex(id(self.c))))
 
     def test_closed_repr(self):
         self.c.close()
         self.failUnlessEqual(
             repr(self.c),
-            ("<closed Collection 'docs/data/test_uk.shp:test_uk', mode 'r' "
+            ("<closed Collection 'docs/data/test_uk.shp:0', mode 'r' "
             "at %s>" % hex(id(self.c))))
 
     def test_path(self):
         self.failUnlessEqual(self.c.path, "docs/data/test_uk.shp")
 
     def test_name(self):
-        self.failUnlessEqual(self.c.name, "test_uk")
+        self.failUnlessEqual(self.c.name, 0)
     
     def test_mode(self):
         self.failUnlessEqual(self.c.mode, "r")
@@ -92,7 +92,7 @@ class ReadingTest(unittest.TestCase):
     
     def test_schema(self):
         s = self.c.schema['properties']
-        self.failUnlessEqual(s['CAT'], "float")
+        self.failUnlessEqual(s['CAT'], "float:16")
         self.failUnlessEqual(s['FIPS_CNTRY'], "str")
 
     def test_closed_schema(self):
@@ -137,7 +137,7 @@ class ReadingTest(unittest.TestCase):
 
     def test_context(self):
         with fiona.open("docs/data/test_uk.shp", "r") as c:
-            self.failUnlessEqual(c.name, "test_uk")
+            self.failUnlessEqual(c.name, 0)
             self.failUnlessEqual(len(c), 48)
         self.failUnlessEqual(c.closed, True)
 
@@ -170,7 +170,7 @@ class UnsupportedDriverTest(unittest.TestCase):
             'properties': {'label': 'str', u'verit\xe9': 'int'} }
         self.assertRaises(
             DriverError, 
-            fiona.open, "/tmp/foo", "w", "FileGDB", schema=schema)
+            fiona.open, "/tmp/foo", "w", "Bogus", schema=schema)
 
 # The file writing tests below presume we can write to /tmp.
 
@@ -181,7 +181,7 @@ class GenericWritingTest(unittest.TestCase):
             'geometry': 'Point', 
             'properties': {'label': 'str', u'verit\xe9': 'int'} }
         self.c = fiona.open(
-                "test-no-iter.shp", 
+                "/tmp/test-no-iter.shp", 
                 "w", 
                 "ESRI Shapefile", 
                 schema=schema,
@@ -387,9 +387,9 @@ class CollectionTest(unittest.TestCase):
         self.assertRaises(ValueError, fiona.open, "/tmp/bogus.shp", "r+")
 
     def test_w_args(self):
-        self.assertRaises(FionaValueError, fiona.open, "test-no-iter.shp", "w")
+        self.assertRaises(FionaValueError, fiona.open, "/tmp/test-no-iter.shp", "w")
         self.assertRaises(
-            FionaValueError, fiona.open, "test-no-iter.shp", "w", "Driver")
+            FionaValueError, fiona.open, "/tmp/test-no-iter.shp", "w", "Driver")
 
     def test_no_path(self):
         self.assertRaises(IOError, fiona.open, "no-path.shp", "a")
@@ -398,6 +398,6 @@ class CollectionTest(unittest.TestCase):
         self.assertRaises(IOError, fiona.open, "PG:dbname=databasename", "r")
 
     def test_no_read_directory(self):
-        self.assertRaises(ValueError, fiona.open, ".", "r")
+        self.assertRaises(ValueError, fiona.open, "/dev/null", "r")
 
 
